### What is Algop?
		Algop is a collection of common used algorithms implemented in python as functions

## To Use
``pip3 install algop``




|Parameters|Default  | Key|  
|---------|--|--|
| array        | none  |All|
| say        | false  |All|
| target        | None  |2|



## Current 
|  Algorithm| Done  | Key|
|--|--| --|
| Bubble sort  | ✅ | 0|
| Insertion sort  | ✅ |1|
| Two Number Sum  | ✅ |2|